==> haskell-fsnotify-0.4.3.0-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fsnotify
version:              0.4.3.0
visibility:           public
id:                   fsnotify-0.4.3.0-21NZ84AyB0D6HbRoRGqidE
key:                  fsnotify-0.4.3.0-21NZ84AyB0D6HbRoRGqidE
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage:             https://github.com/haskell-fswatch/hfsnotify
synopsis:             Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification, and deletion notification. This library builds upon existing libraries for platform-specific Windows, Mac, and Linux filesystem event notification.

category:             Filesystem
abi:                  1aeeef99b3d862f729706569e4874d5d
exposed:              True
exposed-modules:      System.FSNotify System.FSNotify.Devel
hidden-modules:
    System.FSNotify.Find System.FSNotify.Listener System.FSNotify.Path
    System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux
    System.FSNotify.Linux.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/fsnotify-0.4.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fsnotify-0.4.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fsnotify-0.4.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fsnotify
hs-libraries:         HSfsnotify-0.4.3.0-21NZ84AyB0D6HbRoRGqidE
depends:
    async-2.2.5-CA4aEq3ECoz7BppWAZygZ1 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 hinotify-0.4.2-6pqNHDJDUfPA0QhOGx1Tk8
    monad-control-1.0.3.1-JhIUlMwO22REEhKxuYKLpf
    safe-exceptions-0.1.7.4-2FJBdfOuy5GJXMppmu6xCS text-2.0.2
    time-1.12.2 unix-2.7.3 unix-compat-0.7.4.1-7O49sxXSp3B9cDegRW2Oej

haddock-interfaces:   /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html:         /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fsnotify-0.4.3.0-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fsnotify
version:              0.4.3.0
visibility:           public
id:                   fsnotify-0.4.3.0-7UHi5PA6ZHO3xsiJQmnOlK
key:                  fsnotify-0.4.3.0-7UHi5PA6ZHO3xsiJQmnOlK
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage:             https://github.com/haskell-fswatch/hfsnotify
synopsis:             Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification, and deletion notification. This library builds upon existing libraries for platform-specific Windows, Mac, and Linux filesystem event notification.

category:             Filesystem
abi:                  75d76115ba60e1e7509db5f4b2cc1e26
exposed:              True
exposed-modules:      System.FSNotify System.FSNotify.Devel
hidden-modules:
    System.FSNotify.Find System.FSNotify.Listener System.FSNotify.Path
    System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux
    System.FSNotify.Linux.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/fsnotify-0.4.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fsnotify-0.4.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fsnotify-0.4.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fsnotify
hs-libraries:         HSfsnotify-0.4.3.0-7UHi5PA6ZHO3xsiJQmnOlK
depends:
    async-2.2.5-6I3Om2iOc9KLV2rb6dASmz base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 hinotify-0.4.2-KvwosRMoeevKj5IBmNc8TI
    monad-control-1.0.3.1-GYvvySxcDDsKr3A3afhWG
    safe-exceptions-0.1.7.4-43DSHUzp09v7o2yrgwFUvA text-2.0.2
    time-1.12.2 unix-2.7.3 unix-compat-0.7.4.1-Gp2OJygcIQQ2h6Czdh8sny

haddock-interfaces:   /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html:         /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
